@@ -5,19 +5,29 @@ options(
         name="uRSSus",
         packages=['urssus', 
           'urssus.ui', 
+          'urssus.util',
           'urssus.templates', 
           'urssus.versioning', 
-          'urssus.versioning.versions'],
-        version="0.2.0",
+          'urssus.versioning.versions', 
+          'urssus.GoogleReader', 
+          'urssus.GoogleReader.web', 
+          'urssus.GoogleReader.web.resolvUrl', 
+          ],
+        version="0.2.9",
         author="Roberto Alsina",
         author_email='ralsina@netmanagers.com.ar',  
-        package_data = {'urssus.templates': ['*.tmpl', '*.css'],
+        package_data = {'urssus.templates': ['*.tmpl', '*.css', '*.js'],
                         'urssus.versioning': ['*.cfg'], 
                        }, 
-        entry_points = {'gui_scripts': ['urssus = urssus.urssus:main'], 
+        entry_points = {'gui_scripts': ['urssus = urssus.main:main'], 
                         'console_scripts': ['urssus_upgrade_db = urssus.database:main'], 
                         }, 
-        install_requires = ['SQLAlchemy==0.4.6', 'Elixir==0.5.2', 'processing', 'sqlalchemy-migrate'], 
+        install_requires = ['SQLAlchemy==0.4.6', 
+                            'Elixir==0.5.2', 
+                            'processing', 
+                            'sqlalchemy-migrate', 
+                            'simplejson'],
+        extras_require = {'Twitter':  ["twitter"] }, 
         description = 'A multiplatform GUI news agregator.', 
         license = 'GPLv2', 
         keywords = 'atom rss pyqt', 
@@ -39,7 +49,13 @@ ralsina at netmanagers dot com dot ar.
 def sdist():
   """Overrides sdist to make sure that our setup.py is generated."""
   pass
-  
+
+@task
+@needs(['compile_resource','compile_ui', 'setuptools.command.install'])
+def install():
+  """Generate UI and icon resourcebefore installing."""
+  pass
+
   
 uidir=os.path.join('urssus', 'ui')
 
